@@ -81,14 +81,21 @@ def hashivault_k8s_auth_config(module):
         desired_state['issuer'] = params.get('issuer')
     desired_state['mount_point'] = mount_point
 
-    keys_updated = desired_state.keys()
     try:
         current_state = client.auth.kubernetes.read_config(mount_point=mount_point)
-        keys_updated = get_keys_updated(current_state, desired_state)
-        if not keys_updated:
-            return {'changed': False}
     except InvalidPath:
-        pass
+        current_state = {}
+
+    ignore_list = [
+        'mount_point',
+        'token_reviewer_jwt',
+    ]
+    keys_updated = get_keys_updated(desired_state, current_state, ignore_list)
+    if 'pem_keys' in keys_updated:
+        if current_state.get('pem_keys', []) == []:
+            keys_updated.remove('pem_keys')
+    if not keys_updated:
+        return {'changed': False}
 
     if not module.check_mode:
         client.auth.kubernetes.configure(**desired_state)
